@@ -1043,6 +1043,24 @@ impl<A, S, D> ArrayBase<S, D> where S: Data<Elem=A>, D: Dimension
         }
     }
 
+    /// Convert any array or array view to a dynamic dimensional array or
+    /// array view (respectively).
+    ///
+    /// ```
+    /// use ndarray::{arr2, ArrayD};
+    ///
+    /// let array: ArrayD<i32> = arr2(&[[1, 2],
+    ///                                 [3, 4]]).into_dyn();
+    /// ```
+    pub fn into_dyn(self) -> ArrayBase<S, IxDyn> {
+        ArrayBase {
+            data: self.data,
+            ptr: self.ptr,
+            dim: self.dim.into_dyn(),
+            strides: self.strides.into_dyn(),
+        }
+    }
+
     /// Act like a larger size and/or shape array by *broadcasting*
     /// into a larger shape, if possible.
     ///
