@@ -1,4 +1,6 @@
 extern crate ndarray;
+#[macro_use]
+extern crate defmac;
 
 use ndarray::{
     RcArray,
@@ -18,7 +20,7 @@ fn remove_axis()
     assert_eq!(Dim([1, 2]).remove_axis(Axis(0)), Dim([2]));
     assert_eq!(Dim([4, 5, 6]).remove_axis(Axis(1)), Dim([4, 6]));
 
-    assert_eq!(Dim(vec![1,2]).remove_axis(Axis(0)), Dim(vec![2]));
+    assert_eq!(Dim(vec![1, 2]).remove_axis(Axis(0)), Dim(vec![2]));
     assert_eq!(Dim(vec![4, 5, 6]).remove_axis(Axis(1)), Dim(vec![4, 6]));
 
     let a = RcArray::<f32, _>::zeros((4,5));
@@ -34,7 +36,7 @@ fn dyn_dimension()
     let a = arr2(&[[1., 2.], [3., 4.0]]).into_shape(vec![2, 2]).unwrap();
     assert_eq!(&a - &a, Array::zeros(vec![2, 2]));
     assert_eq!(a[&[0, 0][..]], 1.);
-    assert_eq!(a[vec![0, 0]], 1.);
+    assert_eq!(a[[0, 0]], 1.);
 
     let mut dim = vec![1; 1024];
     dim[16] = 4;
@@ -43,6 +45,25 @@ fn dyn_dimension()
     assert_eq!(z.shape(), &dim[..]);
 }
 
+#[test]
+fn dyn_remove() {
+    let mut v = vec![1, 2, 3, 4, 5, 6, 7];
+    let mut dim = Dim(v.clone());
+    defmac!(test_remove index => {
+        dim = dim.remove_axis(Axis(index));
+        v.remove(index);
+        assert_eq!(dim.slice(), &v[..]);
+    });
+
+    test_remove!(1);
+    test_remove!(2);
+    test_remove!(3);
+    test_remove!(0);
+    test_remove!(2);
+    test_remove!(0);
+    test_remove!(0);
+}
+
 #[test]
 fn fastest_varying_order() {
     let strides = Dim([2, 8, 4, 1]);
@@ -192,10 +213,11 @@ macro_rules! ndindex {
             }
             let dim = a.shape().to_vec();
             let b = a.broadcast(dim).unwrap();
-            for (i, &elt) in a.indexed_iter() {
+            for (i, &elt) in b.indexed_iter() {
                 let dim = i.into_dimension();
-                assert_eq!(elt, b[dim]);
                 assert_eq!(elt, b[dim.slice()]);
+                assert_eq!(elt, b[&dim]);
+                assert_eq!(elt, b[dim]);
             }
         }
     }
